@@ -3,8 +3,15 @@
 #ifndef cmCMakePolicyCommand_h
 #define cmCMakePolicyCommand_h
 
+#include "cmConfigure.h"
+
+#include <string>
+#include <vector>
+
 #include "cmCommand.h"
 
+class cmExecutionStatus;
+
 /** \class cmCMakePolicyCommand
  * \brief Set how CMake should handle policies
  *
@@ -26,18 +33,6 @@ public:
   bool InitialPass(std::vector<std::string> const& args,
                    cmExecutionStatus& status) CM_OVERRIDE;
 
-  /**
-    * This determines if the command is invoked when in script mode.
-    */
-  bool IsScriptable() const CM_OVERRIDE { return true; }
-
-  /**
-    * The name of the command as specified in CMakeList.txt.
-    */
-  std::string GetName() const CM_OVERRIDE { return "cmake_policy"; }
-
-  cmTypeMacro(cmCMakePolicyCommand, cmCommand);
-
 private:
   bool HandleSetMode(std::vector<std::string> const& args);
   bool HandleGetMode(std::vector<std::string> const& args);
