@@ -3,8 +3,15 @@
 #ifndef cmLinkLibrariesCommand_h
 #define cmLinkLibrariesCommand_h
 
+#include "cmConfigure.h"
+
+#include <string>
+#include <vector>
+
 #include "cmCommand.h"
 
+class cmExecutionStatus;
+
 /** \class cmLinkLibrariesCommand
  * \brief Specify a list of libraries to link into executables.
  *
@@ -26,13 +33,6 @@ public:
    */
   bool InitialPass(std::vector<std::string> const& args,
                    cmExecutionStatus& status) CM_OVERRIDE;
-
-  /**
-   * The name of the command as specified in CMakeList.txt.
-   */
-  std::string GetName() const CM_OVERRIDE { return "link_libraries"; }
-
-  cmTypeMacro(cmLinkLibrariesCommand, cmCommand);
 };
 
 #endif
